#!/bin/bash
# Copyright 2010, 2013, 2016 Michal Žejdl
# fetches daily average problems from RRDed SNMP if* and makes prints in order
# for daily crontab
# input: rrd* variables (conf)
# output: four daily files for each problem; + head printed
# dependence: rrdtool find gawk ls ionice head

confdir=$(dirname $0)/..
config=$confdir/defaults.sh
test -f $config || exit
. $config

srcdir=$rrddir/snmpagent
problems="ifInDiscards ifInErrors ifOutDiscards ifOutErrors"

for dir in $problems; do
	test -e "$rrdstatsdir"/$dir || mkdir -p "$rrdstatsdir"/$dir
done

# last time with numerical results (last UTC midnight)
# END is unusable with regular expression pattern so here is tail
lasttime=$(rrdtool fetch $(find "$srcdir" -type f -wholename '*/ifEntry/*' -mmin -$(($snmpinterval / 60)) -print -quit) AVERAGE -r 86400 -s -2d | gawk -F: '/^[[:digit:]]+:[[:space:]].*[[:digit:]]/ {print $1}' | tail -1)

test "$lasttime" -gt 0 2>/dev/null || exit
# file for compare (test mtime)
touch -d '1970-01-01 UTC '$lasttime' seconds' "$rrdstatsdir"/lasttime

cd "$srcdir"
# in * do not expand when empty
for snmpagent in $(ls); do
	cd "$snmpagent/ifEntry" || continue
	for rrdfile in $(ls); do
		# bypass unusable files
		test "$rrdfile" -ot "$rrdstatsdir/lasttime" && continue
		ifIndex=${rrdfile%.rrd}
		# uni period, day resolution, last two days, not zero/coldStart
		LC_NUMERIC=C ionice -c3 rrdtool fetch "$rrdfile" AVERAGE -r 86400 -s -2d $rrdcached | gawk -v rrdstatsdir="$rrdstatsdir" -v lasttime=$lasttime -v snmpagent="$snmpagent" -v ifIndex="$ifIndex" '/'$lasttime':[[:space:]].*[[:digit:]]/ {if (($4 >= 0.001) && ($4 < 49700)) printf "%-30s %-40s %8.3f\n", snmpagent, ifIndex, $4 >> rrdstatsdir"/ifInDiscards/"lasttime; if (($5 >= 0.001) && ($5 < 49700)) printf "%-30s %-40s %8.3f\n", snmpagent, ifIndex, $5 >> rrdstatsdir"/ifInErrors/"lasttime; if (($9 >= 0.001) && ($9 < 49700)) printf "%-30s %-40s %8.3f\n", snmpagent, ifIndex, $9 >> rrdstatsdir"/ifOutDiscards/"lasttime; if (($10 >= 0.001) && ($10 < 49700)) printf "%-30s %-40s %8.3f\n", snmpagent, ifIndex, $10 >> rrdstatsdir"/ifOutErrors/"lasttime}'
	done
	cd - >/dev/null
done

# sort & short report
date -d '1970-01-01 UTC '$lasttime' seconds'

cd "$rrdstatsdir"
for dir in $problems; do
	if test -f $dir/$lasttime; then
		# consistent crontab sorting (see man page); n is necessary
		LC_ALL=C sort -k3nr $dir/$lasttime > tmpfile
		echo -e "\n$dir"
		case $dir in
		ifInDiscards|ifOutDiscards)
			selector=d
			;;
		ifInErrors|ifOutErrors)
			selector=e
			;;
		esac
		head tmpfile | awk -v selector=$selector '{print $3, "\thttp://home.suas.cz/~zejdl/sit/nana/snmp/mib/ifgraph.php?agent="$1"&index="$2"&u&"selector}'
		mv tmpfile $dir/$lasttime
	fi
done
