-- ip_time is for rresolver.sh
create table if not exists arp (
	mac char(17) not null,
	ip char(15) not null,
	time int not null,
	primary key (mac, ip),
	index mac_time (mac, time),
	index ip (ip),
	index ip_time (ip, time)
);

-- two defaults are needed for dispatcher.sh 
create table if not exists checked (
	mac char(17) primary key,
	dns char(30),
	lastcheck int,
	live enum('y', 'n'),
	snmp enum('y', 'n'),
	hasfdb enum('y', 'n'),
	collecting enum('y', 'n') default 'n',
	lastsnmpread int default 0,
	index dns (dns),
	index snmp (snmp),
	index hasfdb_mac (hasfdb, mac),
	index lastsnmpread (lastsnmpread)
);

create table if not exists fdb (
	switch char(30),
	port int,
	mac char(17),
	time int,
	primary key (switch, mac),
	index switch (switch),
	index switch_port (switch, port),
	index mac (mac),
	index time (time)
);

create table if not exists fdbonly (
	local char(30),
	port int,
	remote char(30),
	primary key (local, port, remote)
);

create table if not exists freshfdb (
	switch char(30),
	port int,
	mac char(17),
	primary key (switch, mac)
);

/*
create table if not exists iface (
	host char(30),
	ifIndex int,
	ifDescr varchar(256),
	ifSpeed int unsigned,
	time int,
	primary key (host, ifDescr)
);
*/

-- ip6_time is for rresolver.sh
create table if not exists nd (
	mac char(17) not null,
	ip6 char(39) not null,
	time int not null,
	primary key (mac, ip6),
	index ip6 (ip6),
	index ip6_time (ip6, time),
	index time (time)
);

create table if not exists peer (
	switcha char(30),
	porta int,
	portb int,
	switchb char(30),
	time int,
	unique key linka (switcha, porta),
	unique key linkb (switchb, portb),
	unique key peering (switcha, switchb)
);

-- fixed address length, FQDN hostname, TTL is 4 B signed, mysql unixtime is int
-- rresolver.sh needs null in name, so there must be unique key, not primary
create table if not exists rr4 (
	address char(15),
	name varchar(255),
	ttl int,
	time int,
	unique key address_name (address, name),
	key (address),
	key (name),
	key (ttl),
	key (time)
);

create table if not exists rr6 (
	address char(39),
	name varchar(255),
	ttl int,
	time int,
	unique key address_name (address, name),
	key (name),
	key (ttl),
	key (time)
);

create table if not exists sys (
	host char(30) primary key,
	sysDescr varchar(256),
	sysObjectID varchar(256),
	sysUpTime int unsigned,
	sysContact varchar(256),
	sysName varchar(256),
	sysLocation varchar(256),
	time int
);

create table if not exists uplink (
	switch char(30),
	port int,
	router char(17),
	time int,
	primary key (switch, router)
);

-- end of 0.4.0

create table if not exists snmp4 (
	address char(15) primary key,
	time int not null,
	status tinyint unsigned not null,
	agent int,
	get int,
	key (time),
	key (status),
	key (agent),
	key (get)
);

create table if not exists snmp6 (
	address char(39) primary key,
	time int not null,
	status tinyint unsigned not null,
	agent int,
	get int,
	key (time),
	key (status),
	key (agent),
	key (get)
);

-- sysif is reduced (100) because of this error:
-- Specified key was too long; max key length is 1000 bytes
create table if not exists snmpagent (
	id int auto_increment primary key,
	time int not null,
	sysDescr varchar(256) not null,
	sysObjectID varchar(256) not null,
	sysUpTime int unsigned not null,
	sysContact varchar(256) not null,
	sysName varchar(256) not null,
	sysLocation varchar(256) not null,
	sysServices tinyint not null,
	ifNumber int not null,
	dot1dTpFdbEntry enum('n', 'y') not null,
	ifXEntry enum('n', 'y') not null,
	collecting enum('n', 'y') not null,
	collected int not null default 0,
-- give up, uniqueness can not be reached with stripped keys
--	unique key sysif (sysDescr(100), sysObjectID, sysContact(100), sysName, sysLocation(100), sysServices, ifNumber),
	key (time),
	key (sysDescr),
	key (sysObjectID),
	key (sysUpTime),
	key (sysContact),
	key (sysName),
	key (sysLocation),
	key (sysServices),
	key (ifNumber),
	key (collected)
);

create table if not exists mibapc (
	agent int primary key,
	time int not null,
	upsBasicIdentModel varchar(256) not null,
	upsAdvBatteryCapacity int unsigned not null,
	upsAdvBatteryTemperature int unsigned not null,
	upsAdvBatteryRunTimeRemaining int unsigned not null,
	upsAdvOutputLoad int unsigned not null,
	upsAdvTestDiagnosticsResults int not null,
	upsAdvTestLastDiagnosticsDate varchar(256) not null,
	upsAdvTestCalibrationResults int not null,
	upsAdvTestCalibrationDate varchar(256) not null,
	upsBasicStateOutputState char(64) not null,
	key (time),
	key (upsBasicIdentModel)
);

-- remove old table (replaced with mibapc)
drop table if exists apc;

create table if not exists mibifentry (
	agent int not null,
	start int not null,
	time int not null,
	ifIndex int not null,
	ifDescr varchar(256) not null,
	ifType int not null,
	ifMtu int not null,
	ifSpeed int unsigned not null,
	ifPhysAddress varchar(256) not null,
	ifAdminStatus int not null,
	ifOperStatus int not null,
	ifLastChange int unsigned not null,
	primary key (agent, ifIndex),
	key (start),
	key (time),
	key (ifDescr),
	key (ifSpeed),
	key (ifPhysAddress)
);

create table if not exists mibifxentry (
	agent int not null,
	start int not null,
	time int not null,
	ifIndex int not null,
	ifName varchar(256) not null,
	ifLinkUpDownTrapEnable int not null,
	ifHighSpeed int unsigned not null,
	ifPromiscuousMode int not null,
	ifConnectorPresent int not null,
	primary key (agent, ifIndex),
	key (start),
	key (time),
	key (ifName),
	key (ifHighSpeed)
);

create table if not exists mibportifindex (
	agent int not null,
	time int not null,
	port int not null,
	ifIndex int not null,
	primary key (agent, port),
	key (time),
	key (ifIndex)
);

create table if not exists mibfdbport (
	agent int not null,
	time int not null,
	mac char(17) not null,
	port int not null,
	primary key (agent, mac),
	key (agent),
	key agent_port (agent, port),
	key (time),
	key (mac)
);

-- 2016-09-01 remove the old table (replaced with mibifentry)
drop table if exists iface;
