#!/bin/bash
# Copyright 2016 Michal Žejdl
# draw a graph of cpu/mem values from 3Com hwDevice RRD file

# at least five args are required
test $# -lt 5 && exit

rrdbasedir=$1
rrdfile=$2
outputdir=$3
starttime=$4
endtime=$5

# make the remote flush possible
cd $rrdbasedir || exit

test -d "$outputdir" || mkdir -p "$outputdir" || exit

# lazy (-z) is handy
options="-s $starttime -e $endtime -z"

# append rrdcached
test $# -gt 5 && options="$options --daemon $6"

# The overall CPU cost percentage in the last 5 minutes period.
rrdtool graph $outputdir/3com-cpu-$starttime-$endtime.png $options \
-t "CPU cost" -v "percentage" \
DEF:cpua=$rrdfile:hwCpuCostRatePer5Mi:AVERAGE \
DEF:cpun=$rrdfile:hwCpuCostRatePer5Mi:MIN \
DEF:cpum=$rrdfile:hwCpuCostRatePer5Mi:MAX \
DEF:cpul=$rrdfile:hwCpuCostRatePer5Mi:LAST \
VDEF:cpuaa=cpua,AVERAGE \
VDEF:cpunn=cpun,MINIMUM \
VDEF:cpumm=cpum,MAXIMUM \
VDEF:cpull=cpul,LAST \
TEXTALIGN:left \
AREA:cpua#0000CC:"used" \
GPRINT:cpuaa:"avg\: %6.2lf %s" \
GPRINT:cpunn:"min\: %6.2lf %s" \
GPRINT:cpumm:"max\: %6.2lf %s" \
GPRINT:cpull:"lst\: %6.2lf %s\l" \
COMMENT:" \l" \
COMMENT:" "

# the total size of the memory module
# the free size of the memory
# the used size of the raw slice memory
rrdtool graph $outputdir/3com-mem-$starttime-$endtime.png $options \
-t "memory" -v "bytes" \
DEF:mta=$rrdfile:hwMemSize:AVERAGE \
DEF:mtn=$rrdfile:hwMemSize:MIN \
DEF:mtm=$rrdfile:hwMemSize:MAX \
DEF:mtl=$rrdfile:hwMemSize:LAST \
DEF:mfa=$rrdfile:hwMemFree:AVERAGE \
DEF:mfn=$rrdfile:hwMemFree:MIN \
DEF:mfm=$rrdfile:hwMemFree:MAX \
DEF:mfl=$rrdfile:hwMemFree:LAST \
DEF:mua=$rrdfile:hwMemRawSliceUsed:AVERAGE \
DEF:mun=$rrdfile:hwMemRawSliceUsed:MIN \
DEF:mum=$rrdfile:hwMemRawSliceUsed:MAX \
DEF:mul=$rrdfile:hwMemRawSliceUsed:LAST \
CDEF:mufa=mua,mfa,+ \
VDEF:mtaa=mta,AVERAGE \
VDEF:mtnn=mtn,MINIMUM \
VDEF:mtmm=mtm,MAXIMUM \
VDEF:mtll=mtl,LAST \
VDEF:mfaa=mfa,AVERAGE \
VDEF:mfnn=mfn,MINIMUM \
VDEF:mfmm=mfm,MAXIMUM \
VDEF:mfll=mfl,LAST \
VDEF:muaa=mua,AVERAGE \
VDEF:munn=mun,MINIMUM \
VDEF:mumm=mum,MAXIMUM \
VDEF:mull=mul,LAST \
TEXTALIGN:left \
LINE2:mta#0000CC:"total" \
GPRINT:mtaa:"avg\: %6.2lf %s" \
GPRINT:mtnn:"min\: %6.2lf %s" \
GPRINT:mtmm:"max\: %6.2lf %s" \
GPRINT:mtll:"lst\: %6.2lf %s\l" \
AREA:mufa#00CC00:"free " \
GPRINT:mfaa:"avg\: %6.2lf %s" \
GPRINT:mfnn:"min\: %6.2lf %s" \
GPRINT:mfmm:"max\: %6.2lf %s" \
GPRINT:mfll:"lst\: %6.2lf %s\l" \
AREA:mua#CC0000:"used " \
GPRINT:muaa:"avg\: %6.2lf %s" \
GPRINT:munn:"min\: %6.2lf %s" \
GPRINT:mumm:"max\: %6.2lf %s" \
GPRINT:mull:"lst\: %6.2lf %s\l"
