#!/bin/bash
# Copyright 2016 Michal Žejdl
# draw a graph of cpu/mem values from Cisco MemProc RRD file

# at least five args are required
test $# -lt 5 && exit

rrdbasedir=$1
rrdfile=$2
outputdir=$3
starttime=$4
endtime=$5

# make the remote flush possible
cd $rrdbasedir || exit

test -d "$outputdir" || mkdir -p "$outputdir" || exit

# lazy (-z) is handy
options="-s $starttime -e $endtime -z"

# append rrdcached
test $# -gt 5 && options="$options --daemon $6"

rrdtool graph $outputdir/cisco-cpu-$starttime-$endtime.png $options \
-t "CPU cost" -v "percentage" \
DEF:cpua=$rrdfile:cpmCPUTotal5minRev:AVERAGE \
DEF:cpun=$rrdfile:cpmCPUTotal5minRev:MIN \
DEF:cpum=$rrdfile:cpmCPUTotal5minRev:MAX \
DEF:cpul=$rrdfile:cpmCPUTotal5minRev:LAST \
VDEF:cpuaa=cpua,AVERAGE \
VDEF:cpunn=cpun,MINIMUM \
VDEF:cpumm=cpum,MAXIMUM \
VDEF:cpull=cpul,LAST \
TEXTALIGN:left \
AREA:cpua#0000CC:"used" \
GPRINT:cpuaa:"avg\: %6.2lf %s" \
GPRINT:cpunn:"min\: %6.2lf %s" \
GPRINT:cpumm:"max\: %6.2lf %s" \
GPRINT:cpull:"lst\: %6.2lf %s\l" \
COMMENT:" "

rrdtool graph $outputdir/cisco-mem-$starttime-$endtime.png $options \
-t "memory" -v "bytes" \
DEF:mfa=$rrdfile:ciscoMemoryPoolFree:AVERAGE \
DEF:mfn=$rrdfile:ciscoMemoryPoolFree:MIN \
DEF:mfm=$rrdfile:ciscoMemoryPoolFree:MAX \
DEF:mfl=$rrdfile:ciscoMemoryPoolFree:LAST \
DEF:mua=$rrdfile:ciscoMemoryPoolUsed:AVERAGE \
DEF:mun=$rrdfile:ciscoMemoryPoolUsed:MIN \
DEF:mum=$rrdfile:ciscoMemoryPoolUsed:MAX \
DEF:mul=$rrdfile:ciscoMemoryPoolUsed:LAST \
CDEF:mufa=mua,mfa,+ \
VDEF:mfaa=mfa,AVERAGE \
VDEF:mfnn=mfn,MINIMUM \
VDEF:mfmm=mfm,MAXIMUM \
VDEF:mfll=mfl,LAST \
VDEF:muaa=mua,AVERAGE \
VDEF:munn=mun,MINIMUM \
VDEF:mumm=mum,MAXIMUM \
VDEF:mull=mul,LAST \
TEXTALIGN:left \
AREA:mufa#00CC00:"free " \
GPRINT:mfaa:"avg\: %6.2lf %s" \
GPRINT:mfnn:"min\: %6.2lf %s" \
GPRINT:mfmm:"max\: %6.2lf %s" \
GPRINT:mfll:"lst\: %6.2lf %s\l" \
AREA:mua#CC0000:"used " \
GPRINT:muaa:"avg\: %6.2lf %s" \
GPRINT:munn:"min\: %6.2lf %s" \
GPRINT:mumm:"max\: %6.2lf %s" \
GPRINT:mull:"lst\: %6.2lf %s\l"
